@@ -168,6 +168,9 @@ class myMatrix:
                     return False
         return True
 
+    def same(self):
+        return myMatrix(self.x(), self.y())
+
 
 
 class myMatrixLoader:
@@ -186,7 +189,7 @@ class myMatrixLoader:
         if dim == 0:
             for j in range(x.y()):
                 self.matlist.append(x.getcolumn(j))
-                if y == None:
+                if y is None:
                     self.flglist.append(None)
                 else:
                     self.flglist.append(y.getcolumn(j))
